==> haskell-sourcemap-0.1.6-28-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-JRxYTTlkk7v4Cp7yCesKax
key: sourcemap-0.1.6-JRxYTTlkk7v4Cp7yCesKax
license: BSD3
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
author: Chris Done
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
abi: 3ae2c743707f684d054e336bdd5c0e42
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-JRxYTTlkk7v4Cp7yCesKax
depends:
    aeson-1.1.2.0-4o7xkQ7uWQx1uZeT7K0c7O
    attoparsec-0.13.1.0-DfCcdDKzvgP57nVHcPqiZF base-4.9.1.0
    bytestring-0.10.8.1 process-1.4.3.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-28iLOIJkebMKusvrEC7TGP
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-LJIvoU0tJqv1F3CcGlqGJ0
key: sourcemap-0.1.6-LJIvoU0tJqv1F3CcGlqGJ0
license: BSD3
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
author: Chris Done
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
abi: f7bfffdc120fc645c382c05d2e488f36
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-LJIvoU0tJqv1F3CcGlqGJ0
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9
    attoparsec-0.13.1.0-DWdB5NAuEI54zL0UJYXwyo base-4.9.1.0
    bytestring-0.10.8.1 process-1.4.3.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
